@@ -136,12 +136,12 @@ Button::parse(XmlReader& reader)
             const char* p = (const char*) reader.getValue();
                 
             // skip trailing spaces
-            while(*p != 0 && isspace(*p))
+            while(*p != 0 && isspace(static_cast<unsigned char>(*p)))
                 ++p;
 
             bool lastspace = tooltip != "";
             for( ; *p != 0; ++p) {
-                if(isspace(*p)) {
+                if(isspace(static_cast<unsigned char>(*p))) {
                     if(!lastspace) {
                         lastspace = true;
                         tooltip += ' ';
