@@ -161,12 +161,12 @@ CheckButton::parse(XmlReader& reader)
             const char* p = GUI_TRANSLATE((const char*) reader.getValue());  
 
             // skip trailing spaces
-            while(*p != 0 && isspace(*p))
+            while(*p != 0 && isspace(static_cast<unsigned char>(*p)))
                 ++p;
 
             bool lastspace = tooltip != "";
             for( ; *p != 0; ++p) {
-                if(isspace(*p)) {
+                if(isspace(static_cast<unsigned char>(*p))) {
                     if(!lastspace) {
                         lastspace = true;
                         tooltip += ' ';
@@ -289,10 +289,7 @@ CheckButton::event(const Event& event)
         case Event::MOUSEBUTTONUP:
             if(event.inside && mclicked) {
                 if(event.mousebutton == SDL_BUTTON_LEFT &&
-                   state == STATE_DISABLED)
-                   break;
-                
-                if(event.mousebutton == SDL_BUTTON_LEFT)
+                   state != STATE_DISABLED)
                   checked = !checked;
                 released(this, event.mousebutton);
                 clicked(this, event.mousebutton);
