@@ -65,7 +65,7 @@ Dialog::Dialog( int type ){
             break;
         default:
             std::stringstream msg;
-            msg <<"Can't open Dialog type " << type << " without assitional parameters.";
+            msg <<"Can't open Dialog type " << type << " without additional parameters.";
             throw std::runtime_error(msg.str());
     }
 }
@@ -307,19 +307,29 @@ void Dialog::setParagraphN( std::string basename, int number, std::string text )
     p->setText( text );
 }
 
+/* 
+ * Show game statistics in dialog and write them to RESULTS_FILENAME
+ * (~/.lincity/results)
+ */
 void Dialog::gameStats(){
      if( !desktop ) {
         std::cerr << "No desktop found.\n";
         return;
     }
-    try {
-        myDialogComponent = loadGUIFile( "gui/gamestats.xml" );
-        assert( myDialogComponent != 0);
-        registerDialog();
-    } catch(std::exception& e) {
-        std::cerr << "Couldn't display message 'gamestats': "
-            << e.what() << "\n";
-        return;
+    bool useExisting = false;
+    myDialogComponent = desktop->findComponent("GameStats");
+    if( myDialogComponent == 0){
+        try {
+            myDialogComponent = loadGUIFile( "gui/gamestats.xml" );
+            assert( myDialogComponent != 0);
+            registerDialog();
+        } catch(std::exception& e) {
+            std::cerr << "Couldn't display message 'gamestats': "
+                << e.what() << "\n";
+            return;
+        }
+    } else {
+        useExisting = true;
     }
     //open File
     char *s;
@@ -390,6 +400,7 @@ void Dialog::gameStats(){
     results << outf << std::endl;
     setParagraphN( "statistic_text", line++, "" );
     results << "" << std::endl;
+
     //as long as Paragraph.cpp stripes leading spaces there has to
     //be something here ----------\ or the stats look strange.
     //                            |
@@ -405,16 +416,6 @@ void Dialog::gameStats(){
 	     group_count[GROUP_ORGANIC_FARM]);
     setParagraphN( "statistic_text", line++, outf );
     results << outf << std::endl;
-    snprintf (outf, maxlength, _(".       Tracks %4d           Roads %4d             Rail %4d")
-	     ,group_count[GROUP_TRACK], group_count[GROUP_ROAD]
-	     ,group_count[GROUP_RAIL]);
-    setParagraphN( "statistic_text", line++, outf );
-    results << outf << std::endl;
-    snprintf (outf, maxlength, _(".    Potteries %4d     Blacksmiths %4d            Mills %4d")
-	     ,group_count[GROUP_POTTERY], group_count[GROUP_BLACKSMITH]
-	     ,group_count[GROUP_MILL]);
-    setParagraphN( "statistic_text", line++, outf );
-    results << outf << std::endl;
     snprintf (outf, maxlength, _(".    Monuments %4d         Schools %4d     Universities %4d")
 	     ,group_count[GROUP_MONUMENT], group_count[GROUP_SCHOOL]
 	     ,group_count[GROUP_UNIVERSITY]);
@@ -425,11 +426,14 @@ void Dialog::gameStats(){
 	     ,group_count[GROUP_CRICKET]);
     setParagraphN( "statistic_text", line++, outf );
     results << outf << std::endl;
-    snprintf (outf, maxlength, _(".   Coal mines %4d       Ore mines %4d         Communes %4d")
-	     ,group_count[GROUP_COALMINE], group_count[GROUP_OREMINE]
-	     ,group_count[GROUP_COMMUNE]);
+    snprintf (outf, maxlength, _("Health centres %4d            Tips %4d         Shanties %4d"),
+	     group_count[GROUP_HEALTH], group_count[GROUP_TIP],
+	     group_count[GROUP_SHANTY]);
     setParagraphN( "statistic_text", line++, outf );
     results << outf << std::endl;
+    setParagraphN( "statistic_text", line++, "" );
+    results << "" << std::endl;
+
     snprintf (outf, maxlength, _(".    Windmills %4d     Coal powers %4d     Solar powers %4d"),
 	     group_count[GROUP_WINDMILL],
 	     group_count[GROUP_COAL_POWER],
@@ -441,16 +445,30 @@ void Dialog::gameStats(){
 	     ,group_count[GROUP_PORT]);
     setParagraphN( "statistic_text", line++, outf );
     results << outf << std::endl;
+    snprintf (outf, maxlength, _(".       Tracks %4d           Roads %4d             Rail %4d")
+	     ,group_count[GROUP_TRACK], group_count[GROUP_ROAD]
+	     ,group_count[GROUP_RAIL]);
+    setParagraphN( "statistic_text", line++, outf );
+    results << outf << std::endl;
+    setParagraphN( "statistic_text", line++, "" );
+    results << "" << std::endl;
+
+    snprintf (outf, maxlength, _(".    Potteries %4d     Blacksmiths %4d            Mills %4d")
+	     ,group_count[GROUP_POTTERY], group_count[GROUP_BLACKSMITH]
+	     ,group_count[GROUP_MILL]);
+    setParagraphN( "statistic_text", line++, outf );
+    results << outf << std::endl;
     snprintf (outf, maxlength, _(".   Light inds %4d      Heavy inds %4d        Recyclers %4d")
 	     ,group_count[GROUP_INDUSTRY_L], group_count[GROUP_INDUSTRY_H]
 	     ,group_count[GROUP_RECYCLE]);
     setParagraphN( "statistic_text", line++, outf );
     results << outf << std::endl;
-    snprintf (outf, maxlength, _("Health centres %4d            Tips %4d         Shanties %4d"),
-	     group_count[GROUP_HEALTH], group_count[GROUP_TIP],
-	     group_count[GROUP_SHANTY]);
+    snprintf (outf, maxlength, _(".   Coal mines %4d       Ore mines %4d         Communes %4d")
+	     ,group_count[GROUP_COALMINE], group_count[GROUP_OREMINE]
+	     ,group_count[GROUP_COMMUNE]);
     setParagraphN( "statistic_text", line++, outf );
     results << outf << std::endl;
+   
     while( line <= 23 ){ //clear remaining lines
         setParagraphN( "statistic_text", line++, "" );
         results << "" << std::endl;
@@ -459,9 +477,11 @@ void Dialog::gameStats(){
     results.close();
         
     free( outf );
-    // connect signals
-    Button* noButton = getButton( *myDialogComponent, "Okay" );
-    noButton->clicked.connect( makeCallback( *this, &Dialog::closeDialogButtonClicked ) );
+    if( !useExisting ){
+        // connect signals
+        Button* noButton = getButton( *myDialogComponent, "Okay" );
+        noButton->clicked.connect( makeCallback( *this, &Dialog::closeDialogButtonClicked ) );
+    }
 }
 
 void Dialog::editMarket(){
