@@ -683,13 +683,13 @@ void GameView::loadTextures()
    preReadCityTexture( CST_COMMUNE_4,         "commune4.png" );
    preReadCityTexture( CST_COMMUNE_5,         "commune5.png" );
    preReadCityTexture( CST_COMMUNE_6,         "commune6.png" );
-   //preReadCityTexture( CST_COMMUNE_7,         "commune7.png" );
+   preReadCityTexture( CST_COMMUNE_7,         "commune7.png" );
    preReadCityTexture( CST_COMMUNE_8,         "commune8.png" );
    preReadCityTexture( CST_COMMUNE_9,         "commune9.png" );
    preReadCityTexture( CST_COMMUNE_10,        "commune10.png" );
    preReadCityTexture( CST_COMMUNE_11,        "commune11.png" );
-   preReadCityTexture( CST_COMMUNE_12,        "commune12.png" );
-   preReadCityTexture( CST_COMMUNE_13,        "commune13.png" );
+   //preReadCityTexture( CST_COMMUNE_12,        "commune12.png" );
+   //preReadCityTexture( CST_COMMUNE_13,        "commune13.png" );
    //preReadCityTexture( CST_COMMUNE_14,        "commune14.png" );
    preReadCityTexture( CST_INDUSTRY_H_C,      "industryhc.png" );
    preReadCityTexture( CST_INDUSTRY_H_L1,      "industryhl1.png" );
@@ -1390,6 +1390,61 @@ void GameView::markTile( Painter& painter, MapPoint tile )
         tileOnScreenPoint.y -= tileHeight; 
         tilerect.move( tileOnScreenPoint );    
         fillDiamond( painter, tilerect );    
+
+        // Draw range for selected_module_type
+        int range = 0;
+        int reduceNW = 0; // substation and market reduce the range to nort west by one. 
+        switch ( selected_module_type ){
+            //case CST_RESIDENCE_LL: break; 
+            //case CST_RESIDENCE_ML: break;
+            //case CST_RESIDENCE_HL: break;
+            //case CST_RESIDENCE_LH: break;
+            //case CST_RESIDENCE_MH: break;
+            //case CST_RESIDENCE_HH: break;
+            //case CST_FARM_O0: break;
+            //case CST_MILL_0: break;
+            case CST_HEALTH:        range = HEALTH_CENTRE_RANGE; break;
+            case CST_CRICKET_1:     range = CRICKET_RANGE; break;
+            case CST_FIRESTATION_1: range = FIRESTATION_RANGE; break;
+            //case CST_SCHOOL: break;
+            //case CST_UNIVERSITY: break;
+            //case CST_TRACK_LR: break;
+            //case CST_ROAD_LR: break;
+            //case CST_RAIL_LR: break;
+            //case CST_EX_PORT: break;
+            //case CST_ROCKET_1: break;
+            //case CST_POWERL_H_L: break;
+            //case CST_POWERS_COAL_EMPTY: break;
+            //case CST_POWERS_SOLAR: break;
+            case CST_SUBSTATION_R:   range = SUBSTATION_RANGE; reduceNW = 1; break;
+            case CST_WINDMILL_1_R:   range = SUBSTATION_RANGE; reduceNW = 1; break; //Windmills are handled like substations
+            //case CST_COMMUNE_1: break;
+            case CST_COALMINE_EMPTY: range = COAL_RESERVE_SEARCH_LEN; break;
+            //case CST_OREMINE_1: break;
+            //case CST_TIP_0: break;
+            //case CST_RECYCLE: break;
+            //case CST_INDUSTRY_L_C: break;
+            //case CST_INDUSTRY_H_C: break;
+            case CST_MARKET_EMPTY:  range = MARKET_RANGE; reduceNW = 1; break;
+            //case CST_POTTERY_0: break;
+            //case CST_BLACKSMITH_0: break;
+            //case CST_MONUMENT_0: break;
+            //case CST_PARKLAND_PLANE: break;
+            //case CST_WATER: break;
+        }
+       	
+        if (range > 0 )
+        {
+        	painter.setFillColor( Color( 0, 0, 128, 64 ) );
+        	Rect2D rangerect( 0,0,
+        	                  tileWidth  * ( 2 * range - reduceNW ) ,
+        	                  tileHeight * ( 2 * range - reduceNW ) );
+        	Vector2 screenPoint = getScreenPoint(tile);
+        	screenPoint.x -= tileWidth  * ( range - 0.5 * reduceNW );
+        	screenPoint.y -= tileHeight * ( range + 1 - reduceNW );
+        	rangerect.move( screenPoint );
+        	fillDiamond( painter, rangerect );         	
+        }           
     }
 }
 
@@ -1425,7 +1480,7 @@ void GameView::draw(Painter& painter)
     //The Corners of The Screen
     //TODO: change here to only draw dirtyRect
     //      dirtyRectangle is the current Clippingarea (if set)
-    //      so we shold get clippingArea (as sonn this is implemented) 
+    //      so we shold get clippingArea (as soon this is implemented) 
     //      and adjust these Vectors:
     Vector2 upperLeft( 0, 0);
     Vector2 upperRight( getWidth(), 0 );
