@@ -137,15 +137,17 @@ void MainMenu::fillLoadMenu( bool save /*= false*/ )
     //read savegames from lc_save_dir so we can use the original save_city()
     DIR* lincityDir = opendir( lc_save_dir );
     if(!lincityDir) {
-#ifdef DEBUG
         std::cerr << "Warning directory " << lc_save_dir << " doesn't exist.\n";
-#endif
         return;
     }
 
     dirent* curfile;
     CheckButton *button;
+
     for(int i=0;i<6;i++) {
+    	dirent* recentfile;
+        PHYSFS_sint64 t = 0;
+
         std::stringstream filestart;
         filestart << i+1 << "_";
         if( save ){
@@ -161,15 +163,31 @@ void MainMenu::fillLoadMenu( bool save /*= false*/ )
             button->clicked.connect(makeCallback(*this,&MainMenu::selectLoadGameButtonClicked));
         }
         while( ( curfile = readdir( lincityDir ) ) ) { 
-            if(std::string( curfile->d_name ).find( filestart.str() ) == 0 )
+            if(std::string( curfile->d_name ).find( filestart.str() ) == 0 ) {
                 // && !( curfile->d_type & DT_DIR  ) ) is not portable. So
                 // don't create a directoy named 2_ in a savegame-directory or
                 // you can no longer load from slot 2.
-                break;
+	        if (t == 0) {
+                    recentfile = curfile;
+                    t = PHYSFS_getLastModTime(recentfile->d_name);
+                } else {
+                    if (PHYSFS_getLastModTime(curfile->d_name) > t) {
+#ifdef DEBUG
+                       	fprintf(stderr," %s is more recent than previous %s\n",
+                                                curfile->d_name, recentfile->d_name);
+#endif
+                        recentfile = curfile;
+                        t = PHYSFS_getLastModTime(recentfile->d_name);
+                    }
+                }
+            }
         }
-        
-        if(curfile)  {
-            std::string f= curfile->d_name;
+#ifdef DEBUG
+        fprintf(stderr,"Most recent file: %s\n\n",recentfile->d_name);
+#endif
+
+        if(t != 0) {
+            std::string f= recentfile->d_name;
             button->setCaptionText(f);
         } else {
             button->setCaptionText(_("empty"));
@@ -238,6 +256,10 @@ MainMenu::loadOptionsMenu()
         currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
         currentCheckButton = getCheckButton(*optionsMenu, "FXVolumeMinus");
         currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
+        currentCheckButton = getCheckButton(*optionsMenu, "TrackPrev");
+        currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
+        currentCheckButton = getCheckButton(*optionsMenu, "TrackNext");
+        currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
         
         Button* currentButton = getButton(*optionsMenu, "BackButton");
         currentButton->clicked.connect( makeCallback(*this, &MainMenu::creditsBackButtonClicked));
@@ -258,6 +280,10 @@ MainMenu::loadOptionsMenu()
     } else {
         getCheckButton(*optionsMenu, "Fullscreen")->uncheck();
     }
+    //current background track
+    musicParagraph = getParagraph( *optionsMenu, "musicParagraph");
+    musicParagraph->setText(getConfig()->playSongName);
+
     optionsMenu->resize(SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h);
 }
 
@@ -318,17 +344,16 @@ MainMenu::selectLoadSaveGameButtonClicked(CheckButton* button , int, bool save )
     std::string fc=button->getCaptionText();
   
     std::string file="";
-    if( !fc.length()) {
-        return;
-    }
-    
-    baseName = fc;
-    if(newGameMenu.get()==currentMenu ) {
-        file=std::string("opening/")+fc+".scn";
-    } else {
-        file=fc;
-    }
     
+    /* I guess this should be the proper way of selecting in the menu.
+       Everytime we check a new button the last one gets unchecked.
+       If the button checked is an empty one, nothing should be opened 
+       Could be done the other way around: the first time an existing item
+       is selected in the menu, an empty one could never be checked again.
+       Anyway I don't think both should be checked, when an empty is checked
+       after an existing one.
+    */
+       
     char *bs[]={"File0","File1","File2","File3","File4","File5",""};
     for(int i=0;std::string(bs[i]).length();i++) {
         CheckButton *b=getCheckButton(*currentMenu,bs[i]);
@@ -339,6 +364,18 @@ MainMenu::selectLoadSaveGameButtonClicked(CheckButton* button , int, bool save )
         }
     }
 
+    if( !fc.length()) {
+        mFilename = "";
+        return;
+    }
+    
+    baseName = fc;
+    if(newGameMenu.get()==currentMenu ) {
+        file=std::string("opening/")+fc+".scn";
+    } else {
+        file=fc;
+    }
+    
     if(newGameMenu.get()==currentMenu) {
         mFilename=PHYSFS_getRealDir( file.c_str() );
     } else {
@@ -426,11 +463,62 @@ void MainMenu::optionsMenuButtonClicked( CheckButton* button, int ){
             initVideo(getConfig()->videoX, getConfig()->videoY);
             loadOptionsMenu();
         }
+    } else if( buttonName == "TrackPrev"){
+        changeTrack(false);
+    } else if( buttonName == "TrackNext"){
+        changeTrack(true);
     } else {
         std::cerr << "MainMenu::optionsMenuButtonClicked " << buttonName << " unknown Button!\n";
     }    
 }
 
+void
+MainMenu::changeTrack( bool next)
+{
+    std::string filename;
+    std::string directory = "music/";
+    std::string fullname;
+    std::string currentname = getConfig()->playSongName;
+    std::string prevname = currentname;
+    std::string nextname = currentname;
+
+    bool hit = false;
+
+    char **files= PHYSFS_enumerateFiles(directory.c_str());
+    char **fptr=files;
+    while(*fptr)
+    {
+        fullname = directory;
+        fullname.append( *fptr );
+        filename.assign( *fptr );
+        
+        if(!PHYSFS_isDirectory(fullname.c_str())){
+            if( filename == currentname ){
+                hit = true;
+            } else if ( !hit ){
+                prevname = filename; 
+            } else {
+                nextname = filename;
+                break;
+            }
+        }
+        fptr++;
+    }
+    PHYSFS_freeList(files);
+
+    if(next){
+        if( nextname != currentname){
+            getSound()->playSound("Click");
+            getSound()->playMusic(nextname);
+        }
+    } else {
+        if( prevname != currentname){
+            getSound()->playSound("Click");
+            getSound()->playMusic(prevname);
+        }
+    }
+    musicParagraph->setText(getConfig()->playSongName);
+}
 void
 MainMenu::quitButtonClicked(Button* )
 {
@@ -482,6 +570,10 @@ MainMenu::newGameButtonClicked(Button* )
 void
 MainMenu::loadGameButtonClicked(Button* )
 {
+    /* FIXME: NG 1.1 initialisation/clear is not enough yet
+     * This should be done in the engine.cpp or simulate.cpp not here:
+     * see clear_game
+     */
     getSound()->playSound( "Click" );
     loadLoadGameMenu();
     switchMenu(loadGameMenu.get());
@@ -506,6 +598,10 @@ MainMenu::creditsBackButtonClicked(Button* )
 void
 MainMenu::newGameStartButtonClicked(Button* )
 {
+    /* FIXME: NG 1.1 initialisation/clear is not enough yet
+     * This should be done in the engine.cpp or simulate.cpp not here:
+     * see clear_game
+     */
     getSound()->playSound( "Click" );
     if( loadCityNG( mFilename ) ){
     	strcpy (given_scene, baseName.c_str());
@@ -519,6 +615,10 @@ void
 MainMenu::newGameStartBareButtonClicked(Button* )
 {
     getSound()->playSound( "Click" );
+    /* FIXME: NG 1.1 initialisation/clear is not enough yet
+     * This should be done in the engine.cpp or simulate.cpp not here:
+     * see clear_game
+     */
     resetGameStats();
     new_city( &main_screen_originx, &main_screen_originy, 0 );
     GameView* gv = getGameView();
@@ -529,6 +629,10 @@ MainMenu::newGameStartBareButtonClicked(Button* )
 
 //looks like not everything es reseted by new_city()
 void MainMenu::resetGameStats(){
+    /* FIXME: NG 1.1 initialisation/clear is not enough yet
+     * This should be done in the engine.cpp or simulate.cpp not here
+     * see clear_game
+     */
     given_scene[0] = 0;
     for( int i = 0; i < monthgraph_size; i++ ){
         monthgraph_pop[i] = 0;
@@ -549,6 +653,10 @@ void
 MainMenu::newGameStartVillageClicked(Button* )
 {
     getSound()->playSound( "Click" );
+    /* FIXME: NG 1.1 initialisation/clear is not enough yet
+     * This should be done in the engine.cpp or simulate.cpp not here
+     * see clear_game
+     */
     resetGameStats();
     new_city( &main_screen_originx, &main_screen_originy, 1 );
     GameView* gv = getGameView();
@@ -584,6 +692,10 @@ MainMenu::gotoMainMenu()
 void
 MainMenu::loadGameLoadButtonClicked(Button *)
 {
+    /* FIXME: NG 1.1 initialisation/clear is not enough yet
+     * This should be done in the engine.cpp or simulate.cpp not here:
+     * see clear_game
+     */
     getSound()->playSound( "Click" );
     if( loadCityNG( mFilename ) ){
         quitState = INGAME;
@@ -594,19 +706,39 @@ MainMenu::loadGameLoadButtonClicked(Button *)
 void
 MainMenu::loadGameSaveButtonClicked(Button *)
 {
-    time_t now = time(NULL);
-    struct tm* datetime = localtime(&now);
-
     getSound()->playSound( "Click" );
     if( file_exists( const_cast<char*>(mFilename.c_str()) ) ){
         std::cout << "remove( " << mFilename << ")\n";
         remove( mFilename.c_str() );
     }
+    /* Build filename */
     std::stringstream newStart;
-    newStart << slotNr << "_" << (1900 + datetime->tm_year) << "-";
-    newStart << std::setfill('0') << std::setw(2);
-    newStart << datetime->tm_mon+1 << "-" << datetime->tm_mday << "_";
-    newStart << datetime->tm_hour << "_" << datetime->tm_min;
+    newStart << slotNr << "_Y";
+    newStart << std::setfill('0') << std::setw(5);
+    fprintf(stderr,"total_time %i\n",total_time);
+    newStart << total_time/1200;
+    newStart << "_Tech";
+    newStart << std::setfill('0') << std::setw(3);
+    newStart << tech_level/10000;
+    newStart << "_Cash";
+    if (total_money >= 0)
+    	newStart << "+";
+    else
+    	newStart << "-";
+    newStart << std::setfill('0') << std::setw(3);
+    int money = abs(total_money);
+    if (money > 1000000000)
+        newStart << money/1000000000 << "G";  
+    else if (money > 1000000)
+        newStart << money/1000000 << "M";  
+    else  if(money > 1000)
+        newStart << money/1000 << "K"; 
+    else
+        newStart << money/1 << "_";
+ 
+    newStart << "_P";
+    newStart << std::setfill('0') << std::setw(5);
+    newStart << housed_population + people_pool;
     std::string newFilename( newStart.str() ); 
     saveCityNG( newFilename );
     fillLoadMenu( true );
@@ -667,17 +799,17 @@ MainMenu::run()
             }
         }
 
+        // give the CPU time to relax... (we are in main menu)
+        SDL_Delay(10);
+
         if(currentMenu->needsRedraw()) {
             currentMenu->draw(*painter);
             flipScreenBuffer();
-        } else {
-            // give the CPU time to relax...
-            SDL_Delay(25);
-        }
+        } 
 
         frame++;
         if(SDL_GetTicks() - ticks > 1000) {
-#ifdef DEBUG
+#ifdef DEBUG_FPS
             printf("FPS: %d.\n", frame);
 #endif
             frame = 0;
