@@ -47,6 +47,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Mps.hpp"
 #include "CheckButton.hpp"
 #include "Dialog.hpp"
+#include "Game.hpp"
+#include "HelpWindow.hpp"
 
 /** List of mapview buttons. The "" entries separate mapview buttons that are
  * switched
@@ -74,6 +76,12 @@ static inline Color makeGrey(const Color &c)
     return Color(b,b,b);
 }
 
+static inline Color makeBlue(const Color &c)
+{
+    Uint8 b=brightness(c);
+    return Color(0,0,b);
+}
+
 static inline Color light(const Color &c,Uint8 b)
 {
     return Color(
@@ -196,7 +204,7 @@ void MiniMap::attachButtons()
 
     for(int i = 0; speedButtons[i] != 0; ++i) {
         CheckButton* b = getCheckButton(*root, speedButtons[i]);
-        // we start in normal speed...
+	setLincitySpeed(SLOW_TIME_FOR_YEAR);
         if(i == 1)
             b->check();
         b->clicked.connect(makeCallback(*this, &MiniMap::speedButtonClicked));
@@ -229,11 +237,15 @@ void MiniMap::attachButtons()
 }
 
 void
-MiniMap::switchButton(CheckButton* button, int)
+MiniMap::switchButton(CheckButton* button, int mousebutton)
 {
     if( !alreadyAttached ){
         return;
     }
+    if(mousebutton == SDL_BUTTON_RIGHT ) {
+            getGame()->showHelpWindow( "dialogs" );
+    }
+
     if(button->getName() == "SwitchGlobalMPS") {
         //cycle through global styles
         mps_global_style++;
@@ -368,11 +380,39 @@ std::string getNextButton(const std::string &pName)
     return mapViewButtons[i];
 }
 
-void MiniMap::mapViewButtonClicked(CheckButton* button, int)
+void MiniMap::mapViewButtonClicked(CheckButton* button, int mousebutton)
 {
     Component *root = findRoot(this);
     std::string name = button->getName();
     
+    if(mousebutton == SDL_BUTTON_RIGHT ) {
+	// switch button
+        std::string pName=getNextButton(button->getName());
+
+        if(pName=="MapViewNormal")
+            getGame()->showHelpWindow( "msb-normal" );
+        else if (pName=="MapViewUB40")
+	    getGame()->showHelpWindow( "msb-ub40" );
+        else if (pName=="MapViewPollution")
+	    getGame()->showHelpWindow( "msb-pol" );
+        else if (pName=="MapViewFood")
+	    getGame()->showHelpWindow( "msb-starve" );
+        else if (pName=="MapViewPower")
+	    getGame()->showHelpWindow( "msb-power" );
+        else if (pName=="MapViewFire")
+	    getGame()->showHelpWindow( "msb-fire" );
+        else if (pName=="MapViewSport")
+	    getGame()->showHelpWindow( "msb-cricket" );
+        else if (pName=="MapViewHealth")
+	    getGame()->showHelpWindow( "msb-health" );
+        else if (pName=="MapViewCoal")
+	    getGame()->showHelpWindow( "msb-coal" );
+        else if (pName=="MapViewTraffic")
+	    getGame()->showHelpWindow( "msb-transport" );
+    
+    return;
+    }
+     
     DisplayMode newMode=getMode(button->getName());
     if(newMode==mMode) {
         // switch button
@@ -505,6 +545,10 @@ void MiniMap::draw(Painter &painter)
                         mc=getColor(x,y);
                         painter.setFillColor(mc);
                         painter.fillRectangle(Rect2D(x*tilesize,y*tilesize,(x+main_groups[grp].size)*tilesize+1,(y+main_groups[grp].size)*tilesize));
+                    } else if( mMode == COAL ) { //show coal under buildings, too
+                        mc=getColor(x,y);
+                        painter.setFillColor(mc);
+                        painter.fillRectangle(Rect2D(x*tilesize,y*tilesize,(x+1)*tilesize+1,(y+1)*tilesize));
                     }
                 }
             }
@@ -677,6 +721,9 @@ Color MiniMap::getColor(int x,int y) const
             } else {
                 mc=Color(0xFF,0xFF,0xFF);
             }
+            if (MP_GROUP(xx,yy) == GROUP_POWER_LINE)
+                mc=Color(0xFF,0xFF,0); //yellow
+
             mc=light(mc,brightness(getColorNormal(x,y)));
             return mc;
         }
@@ -731,12 +778,19 @@ Color MiniMap::getColor(int x,int y) const
                     return Color(0xFF,0,0);
                 else if ( max > 85 )    //orange
                     return Color(0xFF,0x99,0); 
-	        else if ( max > 50 )    //yellow
-	            return Color(0xFF,0xFF,0); 
-	        else                    //green
-	            return Color(0,0xFF,0); 
-	    } else {
-	        return makeGrey(getColorNormal(x,y));
+	            else if ( max > 50 )    //yellow
+	                return Color(0xFF,0xFF,0); 
+	            else                    //green
+	                return Color(0,0xFF,0); 
+	        } else { //not a Transport, make bluish if in range of a markt
+                if (numof_markets > 0) {
+                    for ( int q = 0; q < numof_markets; q++) {
+	                    if ( (abs (marketx[q] - xx) < MARKET_RANGE)
+                             && (abs (markety[q] - yy) < MARKET_RANGE) )
+	                    return makeBlue(getColorNormal(x,y));
+                    }
+                }
+	            return makeGrey(getColorNormal(x,y));
             }
         }
         case MAX:
