@@ -520,6 +520,8 @@ void mps_global_other_costs()
 
 void mps_global_housing()
 {
+    int days = total_time % NUMOF_DAYS_IN_MONTH +1; // 1..NUMOF_DAYS_IN_MONTH
+    
     int i = 0;
     int tp = housed_population + people_pool;
 
@@ -533,9 +535,9 @@ void mps_global_housing()
     mps_store_sd(i++,_("Shanties"),numof_shanties);
     mps_store_sd(i++,_("Unn Dths"),unnat_deaths);
     mps_store_title(i++,_("Unemployment"));
-    mps_store_sd(i++,_("Claims"),tunemployed_population);
+    mps_store_sd(i++,_("Claims"),tunemployed_population/days);
     mps_store_sfp(i++,_("Rate"),
-		  ((tunemployed_population * 100.0) / tp));
+		  (((tunemployed_population/days) * 100.0) / tp));
     mps_store_title(i++,_("Starvation"));
     mps_store_sd(i++,_("Cases"),tstarving_population);
 
